@@ -14,8 +14,15 @@ class InvenioRecordServiceConfigBuilder(InvenioBaseClassPythonBuilder):
             self.create_parent_modules(python_path)
         output: PythonOutput = self.builder.get_output("python", python_path)
 
+        record_schema_class = self.current_model.get("marshmallow", {}).get(
+            "schema-class", self.current_model.record_schema_class
+        )
+
         context = HyphenMunch(
-            settings=self.settings, current_model=self.current_model, **extra_kwargs
+            settings=self.settings,
+            current_model=self.current_model,
+            record_schema_class=record_schema_class,
+            **extra_kwargs
         )
         template = self.call_components(
             "invenio_before_python_template", template, context=context
